@@ -170,7 +170,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.30'
+__version__ = '0.1.31'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -546,25 +546,28 @@ class LiszDataMixin(ABC):
             return f" {FOCUS_FLOW_PREFIX}{key[:id_len]}"
         return f".{flow_id}" if self.debug_level >= DEBUG_LEVEL_VERBOSE else ""
 
-    def flow_path_from_text(self, text: str) -> List[str]:
+    def flow_path_from_text(self, text: str, skip_check: bool = False) -> List[str]:
         """ restore the full complete flow path from the shortened flow keys generated by :meth:`.flow_path_text`.
 
         :param text:            flow path text - like returned by :meth:`~LiszDataMixin.flow_path_text`.
+        :param skip_check:      pass True to skip the check if the flow path exists in the current self.root_node.
         :return:                flow path list.
         """
         flow_path = list()
         if text not in ('', FLOW_PATH_ROOT_ID):
             node = self.root_node
             for part in text.split(FLOW_PATH_TEXT_SEP):
-                for nid in node:
-                    if nid['id'].startswith(part) and 'node' in nid:
-                        flo_key = nid['id']
-                        path_nid = nid
-                        break
+                if skip_check:
+                    flo_key = part
                 else:
-                    break       # actually not needed, will repair data tree errors
+                    for nid in node:
+                        if nid['id'].startswith(part) and 'node' in nid:
+                            flo_key = nid['id']
+                            node = nid['node']  # type: ignore   # mypy not supports recursive types see issue #731
+                            break
+                    else:
+                        break       # should actually not be needed, will repair data tree errors
                 flow_path.append(id_of_flow('enter', 'item', flo_key))
-                node = path_nid['node']         # type: ignore   # mypy not supports recursive types see issue #731
         return flow_path
 
     def flow_path_node(self, flow_path: List[str] = None, create: bool = False) -> LiszNode:
